@@ -25,12 +25,13 @@ namespace morphodita {
 
 class morpho_ids {
  public:
-  enum morpho_id { CZECH = 0, ENGLISH = 1, GENERIC = 2 };
+  enum morpho_id { CZECH = 0, ENGLISH = 1, GENERIC = 2, EXTERNAL = 3 };
 
   static bool parse(const string& str, morpho_id& id) {
     if (str == "czech") return id = CZECH, true;
     if (str == "english") return id = ENGLISH, true;
     if (str == "generic") return id = GENERIC, true;
+    if (str == "external") return id = EXTERNAL, true;
     return false;
   }
 };
